==> classiq-0.36.1-py3-none-any.whl: classiq/interface/model/quantum_expressions/arithmetic_operation.py <==
from typing import Dict, Mapping, Union

import pydantic

from classiq.interface.generator.arith.arithmetic import (
    ARITHMETIC_EXPRESSION_RESULT_NAME,
    compute_arithmetic_result_type,
)
from classiq.interface.model.handle_binding import (
    HandleBinding,
    SlicedHandleBinding,
    SubscriptHandleBinding,
)
from classiq.interface.model.quantum_expressions.quantum_expression import (
    QuantumExpressionOperation,
)
from classiq.interface.model.quantum_type import QuantumType


class ArithmeticOperation(QuantumExpressionOperation):
    inplace_result: bool = pydantic.Field(
        description="Determines whether the result variable is initialized",
    )

    def initialize_var_types(
        self,
        var_types: Dict[str, QuantumType],
        machine_precision: int,
    ) -> None:
        super().initialize_var_types(var_types, machine_precision)
        self._result_type = compute_arithmetic_result_type(
            self.expression.expr, var_types, machine_precision
        )

    @property
    def wiring_inouts(
        self,
    ) -> Mapping[
        str, Union[SlicedHandleBinding, SubscriptHandleBinding, HandleBinding]
    ]:
        inouts = dict(super().wiring_inouts)
        if self.inplace_result:
            inouts[self.result_name()] = self.result_var
        return inouts

    @property
    def wiring_outputs(self) -> Mapping[str, HandleBinding]:
        if self.inplace_result:
            return {}
        return super().wiring_outputs

    @classmethod
    def result_name(cls) -> str:
        return ARITHMETIC_EXPRESSION_RESULT_NAME

==> classiq-0.37.1-py3-none-any.whl: classiq/interface/model/quantum_expressions/arithmetic_operation.py <==
from typing import Dict, Mapping, Union

import pydantic

from classiq.interface.generator.arith.arithmetic import (
    ARITHMETIC_EXPRESSION_RESULT_NAME,
    compute_arithmetic_result_type,
)
from classiq.interface.model.handle_binding import (
    HandleBinding,
    SlicedHandleBinding,
    SubscriptHandleBinding,
)
from classiq.interface.model.quantum_expressions.quantum_expression import (
    QuantumAssignmentOperation,
)
from classiq.interface.model.quantum_type import QuantumType


class ArithmeticOperation(QuantumAssignmentOperation):
    inplace_result: bool = pydantic.Field(
        description="Determines whether the result variable is initialized",
    )

    def initialize_var_types(
        self,
        var_types: Dict[str, QuantumType],
        machine_precision: int,
    ) -> None:
        super().initialize_var_types(var_types, machine_precision)
        self._result_type = compute_arithmetic_result_type(
            self.expression.expr, var_types, machine_precision
        )

    @property
    def wiring_inouts(
        self,
    ) -> Mapping[
        str, Union[SlicedHandleBinding, SubscriptHandleBinding, HandleBinding]
    ]:
        inouts = dict(super().wiring_inouts)
        if self.inplace_result:
            inouts[self.result_name()] = self.result_var
        return inouts

    @property
    def wiring_outputs(self) -> Mapping[str, HandleBinding]:
        if self.inplace_result:
            return {}
        return super().wiring_outputs

    @classmethod
    def result_name(cls) -> str:
        return ARITHMETIC_EXPRESSION_RESULT_NAME
